#!/usr/bin/python

# some small script to manage releases
import os
import shlex
import shutil
import subprocess
import sys

class _Getch:
    """Gets a single character from standard input.  Does not echo to the screen."""
    def __init__(self):
        try:
            self.impl = _GetchWindows()
        except ImportError:
            self.impl = _GetchUnix()

    def __call__(self): return self.impl()


class _GetchUnix:
    def __init__(self):
        import tty, sys

    def __call__(self):
        import sys, tty, termios
        fd = sys.stdin.fileno()
        old_settings = termios.tcgetattr(fd)
        try:
            tty.setraw(sys.stdin.fileno())
            ch = sys.stdin.read(1)
        finally:
            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
        return ch


class _GetchWindows:
    def __init__(self):
        import msvcrt

    def __call__(self):
        import msvcrt
        return msvcrt.getch()


def cmd(command, stop_on_fail=True):
    result = cmd_args(shlex.split(command))
    if stop_on_fail and result != 0:
        print("Error executing %s" % command)
        sys.exit(result)
    else:
        return result


def cmd_args(arguments):
    proc = subprocess.Popen(arguments)
    stdout, _ = proc.communicate()
    return proc.returncode

def ask(message, accepted=['Y', 'y', '\r']):
    sys.stdout.write(message)
    char = _Getch()()
    print(char)
    return char in accepted

def read_version():
    with open('VERSION') as inf:
        line = inf.readline().strip()
    return line

# get necessary context
version = read_version()
targetdir = "autonta-%s" % version
tarname = "autonta-%s.tar" % version
zipname = "%s.gz" % tarname

# check changelog
print("Changelog:")
cmd("cat Changelog")
if not ask("Is the changelog ok? [Y/n] "):
    print("Aborting release, edit Changelog")
    sys.exit()

# create release
if os.path.exists(targetdir):
    shutil.rmtree(targetdir)
shutil.copytree(".", targetdir, ignore=shutil.ignore_patterns('*.tar.gz', '.git*'))

# create tarball
print("Creating tarball %s " % zipname)
cmd("tar -cf %s %s" % (tarname, targetdir))

sys.exit(0)
cmd("gzip -n %s" % (tarname))

# show hash
print("tar archive created. sha256 hash:")
cmd("sha256sum %s" % zipname)

if 'AUTONTA_PUBLISH_TARGET' not in os.environ:
    print("AUTONTA_PUBLISH_TARGET not set in environment, not publishing")
else:
    if ask("Shall I copy the tarball to the release page? [Y/n] "):
        command =  "scp %s %s" % (zipname, os.environ['AUTONTA_PUBLISH_TARGET'])
        print(command)
        cmd(command)


